"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.summaryReporter = void 0;
const reportTestsErrors_js_1 = require("./reportTestsErrors.js");
const reportTestFileErrors_js_1 = require("./reportTestFileErrors.js");
const TestRunnerLogger_js_1 = require("../logger/TestRunnerLogger.js");
const color = ([x, y]) => (z) => `\x1b[${x}m${z}\x1b[${y}m${reset}`;
const reset = `\x1b[0m\x1b[0m`;
const green = color([32, 89]);
const red = color([31, 89]);
const dim = color([2, 0]);
/** Test reporter that summarizes all test for a given run */
function summaryReporter(opts) {
    const { flatten = false } = opts !== null && opts !== void 0 ? opts : {};
    let args;
    let favoriteBrowser;
    const logger = new TestRunnerLogger_js_1.TestRunnerLogger();
    function log(name, passed, prefix = '  ', postfix = '') {
        const sign = passed ? green('✓') : red('𐄂');
        if (flatten)
            logger.log(`${sign} ${prefix} ${name}${postfix}`);
        else
            logger.log(`${prefix}  ${sign} ${name}`);
    }
    function logResults(results, prefix, browser) {
        var _a, _b;
        const browserName = (browser === null || browser === void 0 ? void 0 : browser.name) ? ` ${dim(`[${browser.name}]`)}` : '';
        for (const result of (_a = results === null || results === void 0 ? void 0 : results.tests) !== null && _a !== void 0 ? _a : []) {
            log(result.name, result.passed, prefix, browserName);
        }
        for (const suite of (_b = results === null || results === void 0 ? void 0 : results.suites) !== null && _b !== void 0 ? _b : []) {
            logSuite(suite, prefix, browser);
        }
    }
    function logSuite(suite, parent, browser) {
        const browserName = (browser === null || browser === void 0 ? void 0 : browser.name) ? ` ${dim(`[${browser.name}]`)}` : '';
        let pref = parent ? `${parent} ` : '';
        if (flatten)
            pref += `${suite.name}`;
        else
            logger.log(`${pref}${suite.name}${browserName}`);
        logResults(suite, pref, browser);
    }
    return {
        start(_args) {
            var _a;
            args = _args;
            favoriteBrowser = (_a = args.browserNames.find(name => {
                const n = name.toLowerCase();
                return n.includes('chrome') || n.includes('chromium') || n.includes('firefox');
            })) !== null && _a !== void 0 ? _a : args.browserNames[0];
        },
        reportTestFileResults({ sessionsForTestFile: sessions }) {
            for (const session of sessions) {
                logResults(session.testResults, '', session.browser);
                logger.log('');
            }
        },
        onTestRunFinished({ sessions }) {
            const failedSessions = sessions.filter(s => !s.passed);
            if (failedSessions.length > 0) {
                logger.log('\n\nErrors Reported in Tests:\n\n');
                reportTestsErrors_js_1.reportTestsErrors(logger, args.browserNames, favoriteBrowser, failedSessions);
                reportTestFileErrors_js_1.reportTestFileErrors(logger, args.browserNames, favoriteBrowser, failedSessions, true);
            }
        },
    };
}
exports.summaryReporter = summaryReporter;
//# sourceMappingURL=summaryReporter.js.map